@@ -1,3 +1,4 @@
+mod compressible;
 mod data_channel;
 mod fs_util;
 mod loader;
@@ -5,6 +6,7 @@ mod store;
 mod tokio_util;
 mod unstable_checker;
 
+pub use compressible::*;
 pub use data_channel::*;
 pub use fs_util::*;
 pub use loader::*;
@@ -17,8 +19,8 @@ use deno_core::error::AnyError;
 use std::fmt;
 #[async_trait]
 pub trait ModuleStore: fmt::Debug + Send + Sync {
-    async fn get(&self, specifier: &str) -> Result<String, AnyError>;
-    async fn put(&self, specifier: String, code: String) -> Result<(), AnyError>;
+    async fn get(&self, specifier: &str) -> Result<Box<[u8]>, AnyError>;
+    async fn put(&self, specifier: String, code: &[u8]) -> Result<(), AnyError>;
 }
 
 #[cfg(test)]
